"""Project metadata
"""

__all__ = [
    '__title__',
    '__summary__',
    '__url__',
    '__version__',
    '__author__',
    '__email__',
    '__license__']

__title__ = 'configlogging'
__summary__ = 'Simple helper moudle for configuring Python logging'

__url__ = 'https://github.com/dgilland/configlogging'

__version__ = '0.1.1'

__author__ = 'Derrick Gilland'
__email__ = 'dgilland@gmail.com'

__license__ = 'MIT License'
